use actix_web::{get, http, post, web, App, HttpResponse, HttpServer, Responder};
use actix_files::Files;
use sqlite::{Connection, State, Error};

#[actix_web::main]
async fn main() -> Result<(), std::io::Error> {
    let conn = Connection::open("./data/data.db");

    HttpServer::new(|| {
        App::new()
            .service(hello)
            .service(Files::new("/", "./public").index_file("index.html"))
    })
    .bind(("0.0.0.0", 8080))?
    .run()
    .await
}

#[get("/api/hello")]
async fn hello() -> impl Responder {
    HttpResponse::Ok().body("Hello world!")
}

#[get("/api/articles")]
async fn get_articles() -> impl Responder {
    let conn = Connection::open("./data/data.db").unwrap();
    let mut stmt = conn.prepare("SELECT * FROM articles").unwrap();
    let mut articles = Vec::new();

    while let State::Row = stmt.next().unwrap() {
        let id = stmt.read::<i64, _>(0).unwrap();
        let title = stmt.read::<String, _>(1).unwrap();
        let subTitle = stmt.read::<String, _>(2).unwrap();
        let content = stmt.read::<String, _>(3).unwrap();
        articles.push((id, title, subTitle, content));
    }

    HttpResponse::Ok().json(articles)
}
